==> nextcloud-12.0.3-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_texteditor/l10n/es.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "guardando...",
    "saved!" : "¡guardado!",
    "failed!" : "¡falló!",
    "Saved" : "Guardado",
    "There was a problem saving your changes. Click to resume editing." : "Hubo un problema al guardar los cambios. Haga clic para reanudar la edición.",
    "An error occurred!" : "¡Ocurrió un error!",
    "Edit" : "Editar",
    "Mixed" : "Mezclado",
    "Preview" : "Vista previa",
    "New text file" : "Nuevo archivo de texto",
    "New text file.txt" : "Nuevo archivo de texto.txt",
    "You can not open a folder" : "No puedes abrir una carpeta",
    "This file is too big to be opened. Please download the file instead." : "El archivo es muy grande para ser abierto. Por favor, descargue el archivo en lugar de abrirlo.",
    "Cannot read the file." : "No se puede leer el archivo.",
    "Invalid file path supplied." : "Ruta de archivo inválida.",
    "The file is locked." : "El archivo está bloqueado.",
    "An internal server error occurred." : "Error interno del servidor",
    "You can not write to a folder" : "No puedes escribir en una carpeta",
    "Cannot save file as it has been modified since opening" : "No es posible guardar el archivo; pues ha sido modificado",
    "Insufficient permissions" : "Permisos insuficientes",
    "File path not supplied" : "No se ha proporcionado la ruta del archivo",
    "File mtime not supplied" : "No se ha proporcionado la hora de modificación del archivo (mtime)",
    "Text editor" : "Editor de texto",
    "Text file" : "Archivo de texto"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_texteditor/l10n/es.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "guardando...",
    "saved!" : "¡guardado!",
    "failed!" : "¡falló!",
    "Saved" : "Guardado",
    "There was a problem saving your changes. Click to resume editing." : "Ha habido un problema al guardar los cambios. Haga clic para reanudar la edición.",
    "An error occurred!" : "¡Se ha producido un error!",
    "Edit" : "Editar",
    "Mixed" : "Mezclado",
    "Preview" : "Vista previa",
    "New text file" : "Nuevo archivo de texto",
    "New text file.txt" : "Nuevo archivo de texto.txt",
    "You can not open a folder" : "No puedes abrir una carpeta",
    "This file is too big to be opened. Please download the file instead." : "El archivo es muy grande para ser abierto. Por favor, descargue el archivo en lugar de abrirlo.",
    "Cannot read the file." : "No se puede leer el archivo.",
    "Invalid file path supplied." : "Ruta de archivo inválida.",
    "The file is locked." : "El archivo está bloqueado.",
    "An internal server error occurred." : "Error interno del servidor",
    "You can not write to a folder" : "No puedes escribir en una carpeta",
    "Cannot save file as it has been modified since opening" : "No es posible guardar el archivo; pues ha sido modificado",
    "Insufficient permissions" : "Permisos insuficientes",
    "File path not supplied" : "No se ha proporcionado la ruta del archivo",
    "File mtime not supplied" : "No se ha proporcionado la hora de modificación del archivo (mtime)",
    "Share not found" : "Recurso compartido no encontrado",
    "You are not authorized to open this share" : "No estás autorizado a abrir este recurso compartido",
    "Invalid range request" : "Petición de alcance inválido",
    "Text editor" : "Editor de texto"
},
"nplurals=2; plural=(n != 1);");
